@@ -109,7 +109,7 @@ class ConfigSource(dict):
             values = self.get(name, {})
 
         env_config = create_env_config(
-            config_cls, *(self.env_prefix + (name,) if name else ())
+            config_cls, *(self.env_prefix + ((name,) if name else ()))
         )
         values = util.merge_dict(values, env_config)
         # merge environment
@@ -134,7 +134,7 @@ class Config:
     __buvar_config_section__: typing.Optional[str] = skip_section
     __buvar_config_sections__: typing.Dict[str, type] = {}
 
-    def __init_subclass__(cls, section=skip_section, **kwargs):
+    def __init_subclass__(cls, *, section: str = skip_section, **kwargs):
         if section is skip_section:
             return
         if section in cls.__buvar_config_sections__:
@@ -197,6 +197,7 @@ def create_env_config(cls, *env_prefix):
     ):
         env_name = "_".join(map(lambda x: x.upper(), env_prefix + path))
         if env_name in os.environ:
+            logger.debug("Overriding config by env", var=env_name)
             target[path[-1]] = os.environ[env_name]
     return env_config
 
