@@ -90,6 +90,7 @@ class Loader:
         for plugin in plugins:
             plugin = resolve_plugin_func(plugin, caller=sys._getframe(1))
             if plugin not in self._tasks:
+                sl.info("Plugin", plugin=util.fqdn(plugin))
                 # mark plugin as loaded for recursive circular stuff
                 self._tasks[plugin] = []
                 # load plugin
@@ -131,14 +132,18 @@ class Stage:
         self.context = self.context.push()
 
     def load(self, *plugins):
-        @context.run_child(self.context)
+        sl.info("Loading plugins")
+
+        @context.run(self.context)
         def _load():
             self.loop.run_until_complete(self.loader(*plugins))
 
         _load()
 
     def run_tasks(self):
-        @context.run_child(self.context)
+        sl.info("Running tasks", tasks=self.loader.tasks)
+
+        @context.run(self.context)
         def _run_tasks():
             return self.loop.run_until_complete(
                 run(tasks=self.loader.tasks, evt_cancel=self.cancel)
@@ -147,6 +152,7 @@ class Stage:
         return _run_tasks()
 
     def run_teardown(self):
+        sl.info("Teardown", tasks=self.teardown.tasks)
         self.loop.run_until_complete(self.teardown.wait())
 
     def run(self, *plugins):
@@ -164,6 +170,7 @@ class Stage:
         try:
             # stage 1: bootstrap plugins
             self.load(*plugins)
+
             # stage 2: run main task and collect teardown tasks
             return self.run_tasks()
         finally:
